from distutils.core import setup
setup(
        name='nbai2020',
        version='1.0.0',
        py_modules=['nbai2020'],
        author='hhpython',
        author_email='2475061609@qq.com',
        ur1='https://github.com/desion/tidy_page',
        description='A simple printer of nested lists'
      )
